@@ -432,9 +432,9 @@ int main(int argc,char **argv)
     if (((install || test || boot_device || disktab_file || compact) && !argc)
       || (compact && linear && 0)) usage(name);
 #endif
-    if (!nowarn && compact && linear)
-	fprintf(stderr,"Warning: COMPACT may conflict with LINEAR on some "
-	  "systems\n");
+    if (!nowarn && compact && (linear || lba32))
+	fprintf(stderr,"Warning: COMPACT may conflict with %s on some "
+	  "systems\n", lba32 ? "LBA32" : "LINEAR");
     preload_types();
     fd = cfg_open(config_file);
     more = cfg_parse(cf_options);
@@ -500,7 +500,7 @@ int main(int argc,char **argv)
 	    if (ioctl(md_fd,GET_DISK_INFO,&md_disk_info) < 0)
 		die("main: GET_DISK_INFO: %s", strerror(errno));
 	    device = (md_disk_info.major << 8) | md_disk_info.minor;
-	    if (device == 0 && (md_disk_info.state & (1 << MD_DISK_FAULTY))) {
+	    if (device == 0) { /* empty slot left over from recovery process */
 		pass++;
 		continue;
 	    }
