@@ -96,12 +96,7 @@
 #define SETUPSECS	4	/* nr of setup sectors */
 #define VSS_NUM		497	/* address where variable setup size is
 				   stored */
-#ifndef LCF_LARGE_EBDA
 #define MAX_KERNEL_SECS	1024	/* absolute maximum kernel size */
-#else
-#define MAX_KERNEL_SECS	 896	/* absolute maximum kernel size */
-#endif
-
 #define SPECIAL_SECTORS	2	/* special sectors (don't compact) at beginning
 				   of map sections */
 
@@ -152,14 +147,12 @@ PARTS_LOAD= 0x0600			! partition sector load address
 PARTS_SCR = 0x0800			! ditto, for non-boot partitions
 PART_TABLE= 0x07BE			! partition table
 
-#ifndef LCF_LARGE_EBDA
 FIRSTSEG  = 0x9A00
 STACKSEG  = 0x9000
+#ifndef LCF_LARGE_EBDA
 SECONDSEG = 0x9B00			! second stage loader segment
 #else
-FIRSTSEG  = 0x8A00
-STACKSEG  = 0x8000
-SECONDSEG = 0x8B00			! second stage loader segment
+SECONDSEG = 0x0B00			! second stage loader segment
 #endif
 
 INITSEG   = DEF_INITSEG			! we move boot here - out of the way
@@ -171,7 +164,13 @@ DESCR	  = 0x2200			! descriptor load area offset
 DFLCMD	  = 0x2600			! default command line
 MAP	  = 0x2000			! map load area offset
 KEYTABLE  = 0x2800			! keyboard translation table offset
+
+#ifndef LCF_LARGE_EBDA
 PARMLINE  = 0x2a00			! parameter line construction area off.
+#else
+PARMLINE  = 0XB000			! parameter line construction area off.
+#endif
+
 SECOND	  = 0x1000			! second stage loader load address
 SECOND_SS = 0xB000			! second as seen from SS:0000
 SLA_SIZE  = 0x9E00			! setup load area size
